@@ -60,3 +60,7 @@ class Blueprint(SanicBlueprint):  # pylint: disable=abstract-method
     def route_get(self, *args: Any, **kwargs: Any) -> None:
         kwargs['http_method'] = 'GET'
         self.route_method(*args, **kwargs)
+
+    def route_post(self, *args: Any, **kwargs: Any) -> None:
+        kwargs['http_method'] = 'POST'
+        self.route_method(*args, **kwargs)
