@@ -50,4 +50,7 @@ def execute() -> None:
 
     # @TODO: Handle error
     command = commands[command_name]
-    run_async(command.execute_with_context(**cli_args))
+    if isinstance(command, AsyncCommand):
+        run_async(command.execute_with_context(**cli_args))
+    else:
+        command.execute(**cli_args)
