@@ -4,7 +4,7 @@ from sanic import Sanic
 from tortoise import Tortoise, Model, fields, functions, queryset
 from tortoise.backends.base.client import BaseDBAsyncClient
 from tortoise.manager import Manager as ModelManager
-from tortoise.transactions import in_transaction
+from tortoise.transactions import atomic as with_transaction, in_transaction
 
 
 __all__ = (
@@ -14,6 +14,7 @@ __all__ = (
     'functions',
     'queryset',
     'in_transaction',
+    'with_transaction',
     'init_db_connection',
     'close_db_connection',
 )
